@@ -40,10 +40,6 @@
    Reference: SVG working draft 3 March 2000, section 8.
 */
 
-#ifndef M_PI
-#define M_PI 3.14159265358979323846
-#endif  /*  M_PI  */
-
 typedef struct _RSVGParsePathCtx RSVGParsePathCtx;
 
 struct _RSVGParsePathCtx {
